==================
Django Nomadlytics
==================

Overview
========

This Django app offers a very light abstraction layer to use a single
method of tracking your data into different SaaS analytics services such
as Mixpanel, Google Analytics, or others.

Contents:

.. toctree::
   :maxdepth: 2

   installation
   configuration
   usage

